import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import React, { useEffect } from 'react';
import PropTypes from 'prop-types';

var InventoryLoadError = function InventoryLoadError(_ref) {
  var component = _ref.component,
      props = _objectWithoutProperties(_ref, ["component"]);

  useEffect(function () {
    console.error("Unable to load iventory component. Failed to load ".concat(component, "."), props);
  }, []);
  return /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("h1", null, "Unable to load inventory component"), /*#__PURE__*/React.createElement("h2", null, "Failed to load ", component), /*#__PURE__*/React.createElement("code", null, "More info can be found in browser console output."));
};

InventoryLoadError.propTypes = {
  component: PropTypes.string
};
export default InventoryLoadError;